﻿using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Text.RegularExpressions;

namespace WrapMethodDemo
{
    public class EpisodeService
    {
        public EpisodeService( EpisodeRepository repository, EmailProvider emailProvider )
        {
            Repository = repository;
            EmailProvider = emailProvider;
        }

        public void CreateComment( CommentDTO comment )
        {
            var saveComment = CreateAndSaveComment(comment);

            SendEmailToAuthor( saveComment );
        }

        protected virtual Comment CreateAndSaveComment(CommentDTO comment)
        {
            var isPossibleSpam = false;
            var patternLenient = @"\w+([-+.]\w+)*@\w+([-.]\w+)*\.\w+([-.]\w+)*";
            var emailRegex = new Regex(patternLenient);

            if ( !emailRegex.IsMatch( comment.EmailAddress ) || comment.Author.Length == 0 )
            {
                isPossibleSpam = true;   
            }

            var commentToSave = new Comment
                                    {
                                        Author = comment.Author,
                                        Comments = comment.Comments,
                                        EmailAddress = comment.EmailAddress,
                                        URL = comment.URL,
                                        IsPossibleSpam = isPossibleSpam
                                    };

            return Repository.Save(commentToSave);
        }

        protected virtual void SendEmailToAuthor( Comment comment )
        {
            Author authorInforamtion = Repository.GetEpisodeAuthorInforamtion(comment);
            EmailProvider.Send("", "", "");
        }

        private EpisodeRepository Repository { get; set; }
        private EmailProvider EmailProvider { get; set; }
    }
}
